@@ -1,12 +1,12 @@
-#!/usr/bin/env perl
+use strict;
+use warnings;
 
 package Git::Hooks::CheckCommit;
 # ABSTRACT: Git::Hooks plugin to enforce commit policies
-$Git::Hooks::CheckCommit::VERSION = '2.9.5';
+$Git::Hooks::CheckCommit::VERSION = '2.9.6';
 use 5.010;
 use utf8;
-use strict;
-use warnings;
+use Carp;
 use Git::Hooks;
 use Git::Repository::Log;
 use List::MoreUtils qw/any none/;
@@ -33,15 +33,17 @@ sub _setup_config {
 
 ##########
 
-# Return common help messages to fix author or committer name/email.
-sub _amend_help {
+# Return common help messages to fix author or committer name/email.  This
+# routine is used to compose some error messages in the routine match_errors
+# below. The "no critic" exemption below is a false positive.
+sub _amend_help {               ## no critic (ProhibitUnusedPrivateSubroutines)
     my ($who) = @_;
     if ($who eq 'author') {
         return 'Please, amend your commit using the --author option to fix the author name/email.';
     } elsif ($who eq 'committer') {
         return 'Please, amend your commit after fixing your user.name and/or user.email configuration options.';
     } else {
-        die "Internal error: invalid who ($who)";
+        croak "Internal error: invalid who ($who)";
     }
 }
 
@@ -70,7 +72,7 @@ sub match_errors {
                     my $data     = $commit->$who_info;
 
                     if (none { $data =~ $_ } @{$checks->{''}}) {
-                        $git->fault(<<EOS, {commit => $commit, option => $info});
+                        $git->fault(<<"EOS", {commit => $commit, option => $info});
 The commit $who $info ($data) is invalid.
 It must match at least one positive option.
 @{[_amend_help($who)]}
@@ -79,7 +81,7 @@ EOS
                     }
 
                     if (any { $data =~ $_ } @{$checks->{'!'}}) {
-                        $git->fault(<<EOS, {commit => $commit, option => $info});
+                        $git->fault(<<"EOS", {commit => $commit, option => $info});
 The commit $who $info ($data) is invalid.
 It matches some negative option.
 @{[_amend_help($who)]}
@@ -100,7 +102,7 @@ sub merge_errors {
     if ($commit->parent() > 1) { # it's a merge commit
         if (my @mergers = $git->get_config($CFG => 'merger')) {
             if (none {$git->match_user($_)} @mergers) {
-                $git->fault(<<EOS, {commit => $commit, option => 'merger'});
+                $git->fault(<<"EOS", {commit => $commit, option => 'merger'});
 Authorization error: you cannot push this commit.
 
 I'm sorry, but you (@{[$git->authenticated_user]}) are not authorized to push
@@ -136,7 +138,7 @@ sub email_valid_errors {
                 }
                 $cache->{email_valid} = Email::Valid->new(@checks);
             } else {
-                $git->fault(<<EOS, {option => 'email-valid.*'});
+                $git->fault(<<'EOS', {option => 'email-valid.*'});
 I could not load the Email::Valid Perl module.
 
 I need it to validate your commit's author and committer as requested by your
@@ -154,7 +156,7 @@ EOS
                 my $email     = $commit->$who_email;
                 unless ($ev->address($email)) {
                     my $details = $ev->details();
-                    $git->fault(<<EOS, {commit => $commit});
+                    $git->fault(<<"EOS", {commit => $commit});
 The commit $who email ($email) failed the $details check.
 @{[_amend_help($who)]}
 EOS
@@ -202,7 +204,7 @@ EOS
             }
 
             if ($identity ne $canonical) {
-                $git->fault(<<EOS, {commit => $commit, option => 'canonical'});
+                $git->fault(<<"EOS", {commit => $commit, option => 'canonical'});
 The commit $who identity isn't canonical.
 It's '$identity' but its canonical form is '$canonical'.
 @{[_amend_help($who)]}
@@ -226,19 +228,19 @@ sub signature_errors {
         my $status = $git->run(qw/log -1 --format='%G?'/, $commit->commit);
 
         if ($status eq 'B') {
-            $git->fault(<<EOS, {commit => $commit, option => 'signature'});
+            $git->fault(<<'EOS', {commit => $commit, option => 'signature'});
 The commit has a BAD GPG signature.
 Please, amend your commit with the -S option to fix it.
 EOS
             ++$errors;
         } elsif ($status eq 'N' && $signature ne 'optional') {
-            $git->fault(<<EOS, {commit => $commit, option => 'signature'});
+            $git->fault(<<'EOS', {commit => $commit, option => 'signature'});
 The commit has NO GPG signature.
 Please, amend your commit with the -S option to add one.
 EOS
             ++$errors;
         } elsif ($status eq 'U' && $signature eq 'trusted') {
-            $git->fault(<<EOS, {commit => $commit, option => 'signature'});
+            $git->fault(<<'EOS', {commit => $commit, option => 'signature'});
 The commit has an UNTRUSTED GPG signature.
 Please, amend your commit with the -S option to add another one.
 EOS
@@ -335,7 +337,7 @@ sub check_ref {
 
     if (my $limit = $git->get_config_integer($CFG => 'push-limit')) {
         if (@commits > $limit) {
-            $git->fault(<<EOS, {ref => $ref, option => 'push-limit'});
+            $git->fault(<<"EOS", {ref => $ref, option => 'push-limit'});
 Are you sure you want to push @{[scalar @commits]} commits to this reference at
 once?
 
@@ -442,18 +444,16 @@ sub check_patchset {
     return commit_errors($git, $commit) == 0;
 }
 
-INIT: {
-    # Install hooks
-    PRE_APPLYPATCH   \&check_pre_commit;
-    POST_APPLYPATCH  \&check_post_commit;
-    PRE_COMMIT       \&check_pre_commit;
-    POST_COMMIT      \&check_post_commit;
-    UPDATE           \&check_affected_refs;
-    PRE_RECEIVE      \&check_affected_refs;
-    REF_UPDATE       \&check_affected_refs;
-    PATCHSET_CREATED \&check_patchset;
-    DRAFT_PUBLISHED  \&check_patchset;
-}
+# Install hooks
+PRE_APPLYPATCH   \&check_pre_commit;
+POST_APPLYPATCH  \&check_post_commit;
+PRE_COMMIT       \&check_pre_commit;
+POST_COMMIT      \&check_post_commit;
+UPDATE           \&check_affected_refs;
+PRE_RECEIVE      \&check_affected_refs;
+REF_UPDATE       \&check_affected_refs;
+PATCHSET_CREATED \&check_patchset;
+DRAFT_PUBLISHED  \&check_patchset;
 
 1;
 
@@ -469,7 +469,7 @@ Git::Hooks::CheckCommit - Git::Hooks plugin to enforce commit policies
 
 =head1 VERSION
 
-version 2.9.5
+version 2.9.6
 
 =head1 SYNOPSIS
 
