@@ -1,12 +1,11 @@
-#!/usr/bin/env perl
+use strict;
+use warnings;
 
 package Git::Hooks::CheckReference;
 # ABSTRACT: Git::Hooks plugin for checking references
-$Git::Hooks::CheckReference::VERSION = '2.9.5';
+$Git::Hooks::CheckReference::VERSION = '2.9.6';
 use 5.010;
 use utf8;
-use strict;
-use warnings;
 use Git::Hooks;
 use List::MoreUtils qw/any none/;
 
@@ -54,7 +53,7 @@ sub check_ref {
         next unless ref $acl->{spec} ? $ref =~ $acl->{spec} : $ref eq $acl->{spec};
         if (index($acl->{action}, $action) != -1) {
             unless ($acl->{allow}) {
-                $git->fault(<<EOS, {ref => $ref, option => 'acl'});
+                $git->fault(<<"EOS", {ref => $ref, option => 'acl'});
 The reference name is not allowed due to the following acl:
 
   $acl->{acl}
@@ -69,7 +68,7 @@ EOS
     if ($action eq 'C') {
         if (any  {$ref =~ qr/$_/} $git->get_config($CFG => 'deny') and
             none {$ref =~ qr/$_/} $git->get_config($CFG => 'allow')) {
-            $git->fault(<<EOS, {ref => $ref, option => 'deny'});
+            $git->fault(<<'EOS', {ref => $ref, option => 'deny'});
 The reference name is not allowed.
 Please, check your configuration option.
 EOS
@@ -81,7 +80,7 @@ EOS
             && $git->get_config_boolean($CFG => 'require-annotated-tags')) {
         my $rev_type = $git->run('cat-file', '-t', $new_commit);
         if ($rev_type ne 'tag') {
-            $git->fault(<<EOS, {ref => $ref, option => 'require-annotated-tags'});
+            $git->fault(<<'EOS', {ref => $ref, option => 'require-annotated-tags'});
 This is a lightweight tag.
 The option in your configuration accepts only annotated tags.
 Please, recreate your tag as an annotated tag (option -a).
@@ -110,12 +109,10 @@ sub check_affected_refs {
     return $errors == 0;
 }
 
-INIT: {
-    # Install hooks
-    UPDATE       \&check_affected_refs;
-    PRE_RECEIVE  \&check_affected_refs;
-    REF_UPDATE   \&check_affected_refs;
-}
+# Install hooks
+UPDATE       \&check_affected_refs;
+PRE_RECEIVE  \&check_affected_refs;
+REF_UPDATE   \&check_affected_refs;
 
 1;
 
@@ -131,7 +128,7 @@ Git::Hooks::CheckReference - Git::Hooks plugin for checking references
 
 =head1 VERSION
 
-version 2.9.5
+version 2.9.6
 
 =head1 SYNOPSIS
 
