@@ -1,12 +1,11 @@
-#!/usr/bin/env perl
+use strict;
+use warnings;
 
 package Git::Hooks::CheckRewrite;
 # ABSTRACT: Git::Hooks plugin for checking against unsafe rewrites
-$Git::Hooks::CheckRewrite::VERSION = '2.9.5';
+$Git::Hooks::CheckRewrite::VERSION = '2.9.6';
 use 5.010;
 use utf8;
-use strict;
-use warnings;
 use Path::Tiny;
 use Git::Hooks;
 
@@ -59,7 +58,7 @@ sub check_commit_amend {
     my $record_file = _record_filename($git);
 
     -r $record_file
-        or $git->fault(<<EOS)
+        or $git->fault(<<'EOS')
 I cannot read $record_file.
 Please, check if you forgot to create the pre-commit hook.
 EOS
@@ -87,7 +86,7 @@ EOS
         # $old_commit is reachable by at least one branch, which means
         # the amend was unsafe.
         my $branches = join "\n  ", @branches;
-        $git->fault(<<EOS);
+        $git->fault(<<"EOS");
 You just performed an unsafe "git commit --amend" because your
 original HEAD ($old_commit) is still reachable by the following
 branch(es):
@@ -135,7 +134,7 @@ sub check_rebase {
         # The base commit is reachable by more than one branch, which
         # means the rewrite is unsafe.
         my $branches = join("\n  ", grep {$_ ne $branch} @branches);
-        $git->fault(<<EOS);
+        $git->fault(<<"EOS");
 You just performed an unsafe rebase because it would rewrite commits shared
 by $branch and the following other branch(es):
 
@@ -155,12 +154,10 @@ EOS
     return 1;
 }
 
-INIT: {
-    # Install hooks
-    PRE_COMMIT  \&record_commit_parents;
-    POST_COMMIT \&check_commit_amend;
-    PRE_REBASE  \&check_rebase;
-}
+# Install hooks
+PRE_COMMIT  \&record_commit_parents;
+POST_COMMIT \&check_commit_amend;
+PRE_REBASE  \&check_rebase;
 
 1;
 
@@ -176,7 +173,7 @@ Git::Hooks::CheckRewrite - Git::Hooks plugin for checking against unsafe rewrite
 
 =head1 VERSION
 
-version 2.9.5
+version 2.9.6
 
 =head1 SYNOPSIS
 
